@@ -1,6 +1,7 @@
+if (interactive()) pkgload::load_all()
 test_check_makelist <- function() {
     RUnit::checkException(fakemake:::check_makelist(3))
-    ml <- provide_make_list("package")
+    ml <- provide_make_list()
     RUnit::checkTrue(fakemake:::check_makelist(ml))
     ml1 <- ml
     ml1[[2]]["foo"] <- "invalid item"
